@@ -4,14 +4,16 @@ jQuery(function(){
 		
 	$('#id_app').on('change',function(){
 		var val = $(this).val();
+        var optgroup = $(this).children('option[value="'+val+'"]').text();
+        console.log(optgroup);
 		$('#id_model').html(models);
 		$('#id_model optgroup').each(function(){
-			if($(this).attr('label') == val){
+			if($(this).attr('label') == optgroup){
 				$(this).addClass('selected');
 			}
 		});
 		
-		$('#id_model').children().not('.selected').remove("optgroup");;
+		$('#id_model').children().not('.selected').remove("optgroup");
 	});
 	
 });
