@@ -130,14 +130,22 @@ function googleMapAdmin() {
 
     return self;
 }
-
 jQuery(function() {
-	if($("#id_geoaddress").siblings('#gmap_search').attr('id') == undefined){
-		$("#id_geoaddress").css("width","400px");
-	    $("#id_geoaddress").after("<img id='gmap_search' src='/static/admin/img/icon_searchbox.png' alt='Search' style='cursor:pointer;'>");
-	
-		//console.log($("#gmap_search").attr('src'));
-		    var googlemap = googleMapAdmin();
-		    googlemap.initialize();
-		}
-});
+    var init_upy_map = function(){
+        if($("#id_geoaddress").siblings('#gmap_search').attr('id') == undefined){
+            $("#id_geoaddress").css("width","400px");
+            $("#id_geoaddress").after("<img id='gmap_search' src='/static/admin/img/icon_searchbox.png' alt='Search' style='cursor:pointer;'>");
+            var googlemap = googleMapAdmin();
+            googlemap.initialize();
+        }
+    }
+
+    if($("#id_geoaddress").parents('fieldset').find('h2>a').length > 0){
+        $("#id_geoaddress").parents('fieldset').find('h2>a').on('click',function(){
+            init_upy_map();
+        });
+    }
+    else{
+        init_upy_map();
+    }
+});
\ No newline at end of file
